start method
This function register this device to Pusher Beams service with the given instanceId.
You must call this method as soon as possible in your application (Preferable inside the main function).
Example Usage
void main() async {
// Some code...
await PusherBeams.instance.start('YOUR INSTANCE ID');
]
Throws an Exception in case of failure.
Implementation
@override
Future<void> start(String instanceId) async {
await _pusherBeamsApi.start(UuidValue(instanceId).toString());
}